pub struct Hand { /* private fields */ }Implementations
Sourceimpl Hand
impl Hand
pub fn new() -> Self
pub fn add_card(&mut self, card: Card)
pub fn cards(&self) -> &[Card]
pub fn clear(&mut self)
Sourcepub fn evaluate(&self, community_cards: &[Card]) -> HandRank
pub fn evaluate(&self, community_cards: &[Card]) -> HandRank
Evaluate the best 5-card poker hand from available cards For Texas Hold’em: 2 hole cards + 5 community cards = 7 total
Sourcepub fn evaluate_with_cards(&self, community_cards: &[Card]) -> HandEvaluation
pub fn evaluate_with_cards(&self, community_cards: &[Card]) -> HandEvaluation
Evaluate and return both the rank and the specific 5 cards used